==> aws-java-sdk-config-1.10.54-sources.jar: com/amazonaws/services/config/model/transform/SourceDetailJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.config.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.config.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * SourceDetail JSON Unmarshaller
 */
public class SourceDetailJsonUnmarshaller implements
        Unmarshaller<SourceDetail, JsonUnmarshallerContext> {

    public SourceDetail unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        SourceDetail sourceDetail = new SourceDetail();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("EventSource", targetDepth)) {
                    context.nextToken();
                    sourceDetail.setEventSource(StringJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
                if (context.testExpression("MessageType", targetDepth)) {
                    context.nextToken();
                    sourceDetail.setMessageType(StringJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return sourceDetail;
    }

    private static SourceDetailJsonUnmarshaller instance;

    public static SourceDetailJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new SourceDetailJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-config-1.11.20-sources.jar: com/amazonaws/services/config/model/transform/SourceDetailJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.config.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.config.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * SourceDetail JSON Unmarshaller
 */
public class SourceDetailJsonUnmarshaller implements
        Unmarshaller<SourceDetail, JsonUnmarshallerContext> {

    public SourceDetail unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        SourceDetail sourceDetail = new SourceDetail();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("EventSource", targetDepth)) {
                    context.nextToken();
                    sourceDetail.setEventSource(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("MessageType", targetDepth)) {
                    context.nextToken();
                    sourceDetail.setMessageType(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("MaximumExecutionFrequency",
                        targetDepth)) {
                    context.nextToken();
                    sourceDetail.setMaximumExecutionFrequency(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return sourceDetail;
    }

    private static SourceDetailJsonUnmarshaller instance;

    public static SourceDetailJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new SourceDetailJsonUnmarshaller();
        return instance;
    }
}
